@@ -76,6 +76,9 @@ void AnalitzaTest::testTrivialCalculate_data()
     QTest::newRow("val.e0") << "12.0e-02" << Cn(12e-2);
     QTest::newRow("vale") << "12e-2" << Cn(12e-2);
     QTest::newRow("val") << "12e2" << Cn(12e2);
+
+    QTest::newRow("factorial5") << "factorial(5)" << Cn(120);
+    QTest::newRow("factorial12") << "factorial(12)" << Cn(12*11*10*9*8*7*6*5*4*3*2*1);
     
     QTest::newRow("simple addition") << "2+2" << Cn(4.);
     QTest::newRow("simple power") << "2**99" << Cn(pow(2., 99.));
@@ -445,7 +448,11 @@ void AnalitzaTest::testCorrection_data()
            << QStringLiteral("pu:=n->sum(  comb(n,i)*p^(n-i)*(1-p)*sum(x:x=0..i)  :i=0..(floor((n-1)/2)))")
            << QStringLiteral("pu(5)");
     
+#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
+    QTest::newRow("bug241047") << script << "2.97495e-5";
+#else
     QTest::newRow("bug241047") << script << "2.97495e-05";
+#endif
     
     script.clear();
     script << QStringLiteral("comb:=(n, i)->factorial(n)/(factorial(i)*factorial(n-i))")
