@@ -83,7 +83,7 @@ void SpaceCurveTest::testIncorrect()
 
     PlotBuilder rp = PlotsFactory::self()->requestPlot(Expression(input), Dim3D);
     if(rp.canDraw()) {
-        FunctionGraph* f = rp.create(Qt::red, "lala");
+        FunctionGraph* f = rp.create(Qt::red, QStringLiteral("lala"));
         SpaceCurve* curve = dynamic_cast<SpaceCurve*>(f);
         QVERIFY(curve);
         
